@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 from __future__ import print_function
 
-VERSION = '0.4.7'
+VERSION = '0.4.8'
 
 import os
 import sys
@@ -30,7 +30,7 @@ except AttributeError:
     width = 40
 
 
-def get_args():
+def get_args(raw_args):
     parser = argparse.ArgumentParser(
         description='Simplified kernel rolling tool'
     )
@@ -97,7 +97,7 @@ def get_args():
         help='directory for kernel configs'
     )
 
-    return parser.parse_args()
+    return parser.parse_args(raw_args)
 
 
 def get_latest_kernel_version(kind='stable'):
@@ -116,7 +116,10 @@ def get_current_kernel_version():
 
 
 def get_current_kernel_revision():
-    current_revision = os.uname().release.rsplit('_', 1)[1]
+    current_kernel = os.uname()[2].rsplit('_', 1)
+    if len(current_kernel) < 2:
+        return '0'
+    current_revision = current_kernel[1]
     if all(x in set(string.digits) for x in current_revision):
         return current_revision
     else:
@@ -200,6 +203,8 @@ class Kernel(object):
         else:
             self.config_dir = os.path.expanduser(config_dir.rstrip('/'))
         self.config_dir = os.path.abspath(self.config_dir)
+        if not os.path.isdir(self.config_dir):
+            os.makedirs(self.config_dir, 0o755)
 
         for subdir in ['/sources', '/archives']:
             if not os.path.isdir(self.build_dir + subdir):
@@ -231,12 +236,12 @@ class Kernel(object):
         else:
             testing = ''
 
-        destination = '{0}/archives/linux-{1}.tar.xz'.format(
+        destination = '{0}/archives/linux-{1}.tar.gz'.format(
             self.build_dir,
             self.version
         )
         base_url = 'http://www.kernel.org/pub/linux/kernel'
-        source = '{0}/v{1}/{2}linux-{3}.tar.xz'.format(
+        source = '{0}/v{1}/{2}linux-{3}.tar.gz'.format(
             base_url,
             major,
             testing,
@@ -264,7 +269,7 @@ class Kernel(object):
     @require_attr('version')
     def extract(self):
         destination = '{0}/sources/'.format(self.build_dir)
-        source = '{0}/archives/linux-{1}.tar.xz'.format(
+        source = '{0}/archives/linux-{1}.tar.gz'.format(
             self.build_dir,
             self.version
         )
@@ -280,6 +285,7 @@ class Kernel(object):
         else:
             callback = None
         try:
+            print("Trying to open {0}".format(source))
             archive = TarFileWithProgress.open(source, callback=callback)
             archive.extractall(destination)
         except:
@@ -434,8 +440,8 @@ kernel /boot/vmlinuz-{0}_{1} root={2} ro\n'''.format(
             shutil.rmtree(self.build_dir + '/sources/' + source)
 
 
-def easy_roll():
-    args = get_args()
+def easy_roll(raw_args):
+    args = get_args(raw_args)
     kernel = Kernel(
         build_dir=args.build_dir,
         config_dir=args.config_dir,
@@ -481,4 +487,4 @@ def easy_roll():
         kernel.install()
 
 if __name__ == '__main__':
-    easy_roll()
+    easy_roll(sys.argv[1:])
